Package: precommit
Title: Pre-Commit Hooks
Version: 0.4.3
Author: Lorenz Walthert
Maintainer: Lorenz Walthert <lorenz.walthert@icloud.com>
Description: Useful git hooks for R building on top of the multi-language
    framework 'pre-commit' for hook management. This package provides git
    hooks for common tasks like formatting files with 'styler' or spell
    checking as well as wrapper functions to access the 'pre-commit'
    executable.
License: GPL-3
URL: https://lorenzwalthert.github.io/precommit/,
        https://github.com/lorenzwalthert/precommit
Imports: cli, fs, here, magrittr, purrr, R.cache, rlang, rprojroot,
        withr, yaml
Suggests: desc, docopt (>= 0.7.1), git2r, glue, knitr, lintr, pkgload,
        pkgdown, reticulate (>= 1.16), rmarkdown, roxygen2, rstudioapi,
        spelling, styler, testthat (>= 2.1.0), tibble, usethis (>=
        2.0.0)
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 7.3.1
SystemRequirements: git
Config/testthat/parallel: true
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2024-07-22 13:56:23 UTC; lorenz
Repository: CRAN
Date/Publication: 2024-07-22 22:20:05 UTC
Built: R 4.6.0; ; 2026-04-28 08:48:56 UTC; unix
