# Generated by roxygen2: do not edit by hand

export(autoupdate)
export(diff_requires_run_roxygenize)
export(dirs_R.cache)
export(install_precommit)
export(may_require_permanent_cache)
export(open_config)
export(open_wordlist)
export(path_pre_commit_exec)
export(path_precommit_exec)
export(precommit_docopt)
export(robust_purl)
export(roxygen_assert_additional_dependencies)
export(roxygenize_with_cache)
export(snippet_generate)
export(uninstall_precommit)
export(update_precommit)
export(use_ci)
export(use_precommit)
export(use_precommit_config)
export(version_precommit)
importFrom(R.cache,saveCache)
importFrom(magrittr,"%>%")
